<?php
namespace Teknisa\SM\Service;

use Teknisa\SM\Factory\Sm00035000MaximoCarenciaPropostaPerfilAcessoFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class Sm00035000MaximoCarenciaPropostaPerfilAcessoService
{
    
    protected $FactoryCarenciaPerfProp;
    protected $Environment;
    protected $newCode;
    protected $entityManager;
    protected $connection;
    
    public function __construct (Sm00035000MaximoCarenciaPropostaPerfilAcessoFactory $FactoryCarenciaPerfProp, Environment $Environment, NewCode $NewCode, EntityManager $EntityManager){
        $this->FactoryCarenciaPerfProp  = $FactoryCarenciaPerfProp;
        $this->Environment  = $Environment;
        $this->newCode = $NewCode;
        $this->entityManager = $EntityManager;
        $this->connection = $this->entityManager->getConnection();
    }
    
     /**
     * A função "validaCarenciaOperador" verifica se já existe 
     * uma carencia cadastrada para o operador indicado.
     */
     
    public function validaCarenciaPerfilAcesso($perfAcesso){
    
        $paramsValidaCarenciaPerfProp = array(
            "NRPERFILACESSO"  => $perfAcesso,
            "NRORG"          => $this->Environment->getNrOrg()
        );
        
        $returnValidaCarenciaPerProp = $this->FactoryCarenciaPerfProp->validaCarenciaPerfilAcesso($paramsValidaCarenciaPerfProp);
        
        return $returnValidaCarenciaPerProp[0]["VALIDAPERF"] != 0;
        
    }
    
    public function insereFaixaDesconto($numeroPerfil,$numeroOperador, $valorPercDe, $valorPercAte, $numeroCarencia, $nrParcelasMax){
        //validar se pode inserir este elemento
        try{
            $resposta;
            $this->connection->beginTransaction();
            if($this->podeInserirFaixaDesconto($numeroPerfil,$numeroOperador, $nrParcelasMax, $numeroCarencia)){
              // sim pegar os params
                $nrorg = $this->Environment->getNrOrg();
                $cdoperador = $this->Environment->getCdOperador();
                $nrFaixaDesc = $this->newCode->getCodeByTableName("FCT_CARENCIAFAIXADESC", $nrorg, 1, 10, true);
                $params = array(
                    "NRCARENCIAFAIXADESC"   => $nrFaixaDesc,
                    "NRCARENCIAPERFIL"      => $numeroPerfil,
                    "NRCARENCIAOPER"        => $numeroOperador,
                    "NRPARCELASMAX"         => $numeroCarencia,
                    "VRPERCDESCDE"          => $valorPercDe,
                    "VRPERCDESCATE"         => $valorPercAte,
                    "NRORG"                 => $nrorg,
                    "NRORGINCLUSAO"         => $nrorg,
                    "CDOPERADOR"            => $cdoperador,
                    "CDOPERINCLUSAO"        => $cdoperador            
                );
                 // insere
                $this->FactoryCarenciaPerfProp->inserirFaixaDesconto($params);
                $this->connection->commit();
                $resposta = "Registro inserido com sucesso";
            }else{
                $this->connection->rollback();
                $resposta = "Registro não foi inserido. \n Motivo: O número de carência supera o máximo ou já foi efetuado o máximo" ;
            }
        }catch(\Exception $e){
                $resposta = "Registro não foi inserido. \n Motivo: " . $e->getMessage();
        }
        return $resposta;
    }
    
    public function atualizaFaixaDesconto($numeroPerfil,$numeroOperador, $valorPercDe, $valorPercAte, $numeroCarencia, $nrParcelasMax, $nrCarencia){
        //validar se pode inserir este elemento
        try{
            $resposta;
            $this->connection->beginTransaction();
            if($this->podeAtualizarFaixaDesconto($numeroPerfil,$numeroOperador, $nrParcelasMax, $numeroCarencia)){
              // sim pegar os params
                $nrorg = $this->Environment->getNrOrg();
                $cdoperador = $this->Environment->getCdOperador();
                $params = array(
                    "NRCARENCIAFAIXADESC"   => $nrCarencia,
                    "NRCARENCIAPERFIL"      => $numeroPerfil,
                    "NRCARENCIAOPER"        => $numeroOperador,
                    "NRPARCELASMAX"         => $numeroCarencia,
                    "VRPERCDESCDE"          => $valorPercDe,
                    "VRPERCDESCATE"         => $valorPercAte,
                    "NRORG"                 => $nrorg,
                    "CDOPERADOR"            => $cdoperador,
                    "CDOPERULTATU"          => $cdoperador,
                    "NRORGULTATU"           => $nrorg
                );
                 // atualiza
                $this->FactoryCarenciaPerfProp->atualizaFaixaDesconto($params);
                $this->connection->commit();
                $resposta = "Registro atualizado com sucesso";
            }else{
                $this->connection->rollback();
                $resposta = "Registro não foi atualizado. \n Motivo: O número de carência supera o máximo ou já foi efetuado o máximo" ;
            }
        }catch(\Exception $e){
                $resposta = "Registro não foi atualizado. \n Motivo: " . $e->getMessage();
        }
        return $resposta;
    }
    
    public function podeInserirFaixaDesconto($nrperfil,$nrOperador, $nrParcelasMax, $nrparcelas){
        if(isset($nrperfil)){
            $params = array("NRPERFILACESSO" => $nrperfil);
            $resposta = $this->FactoryCarenciaPerfProp->validarInsercaoFaixaDescontoPerfil($params);
        }else{
            $params = array("NRPARCNEGOCIO" => $nrOperador);
            $resposta = $this->FactoryCarenciaPerfProp->validarInsercaoFaixaDescontoOperador($params);
        }
        //return ($resposta[0]["QUANTIDADE"] < $nrParcelasMax) && (($resposta[0]["QUANTIDADE"]+$nrparcelas) < $nrParcelasMax);
        return true;
    }
    
    public function podeAtualizarFaixaDesconto($nrperfil,$nrOperador, $nrParcelasMax, $nrparcelas){
        if(isset($nrperfil)){
            $params = array("NRPERFILACESSO" => $nrperfil);
            $resposta = $this->FactoryCarenciaPerfProp->validarInsercaoFaixaDescontoPerfil($params);
        }else{
            $params = array("NRPARCNEGOCIO" => $nrOperador);
            $resposta = $this->FactoryCarenciaPerfProp->validarInsercaoFaixaDescontoOperador($params);
        }
        //return ($resposta[0]["QUANTIDADE"] < $nrParcelasMax) && (($resposta[0]["QUANTIDADE"]+$nrparcelas) < $nrParcelasMax);
        return true;
    }
    
    public function pegarBetweenCarenciaOperador($vrini, $vrfin, $nroperador){
        try{
            $resposta;
            $params = array(
                "NRCARENCIAOPER"    => $nroperador,
                "VRINI"             => $vrini,
                "VRFIN"             => $vrfin
            );
            $existe = $this->FactoryCarenciaPerfProp->pegarBetweenCarenciaOperador($params);
            $resposta = $existe[0]["EXISTE"];
        }catch(\Exception $e){
            $resposta = "1";
        }
        return $resposta;
    }
    
    public function pegarBetweenCarenciaPerfil($vrini, $vrfin, $nroperador){
        try{
            $resposta;
            $params = array(
                "NRPERFILACESSO"    => $nroperador,
                "VRINI"             => $vrini,
                "VRFIN"             => $vrfin
            );
            $existe = $this->FactoryCarenciaPerfProp->pegarBetweenCarenciaPerfil($params);
            $resposta = $existe[0]["EXISTE"];
        }catch(\Exception $e){
            $resposta = "1";
        }
        return $resposta;
    }
}
?>